# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_kubernetes.helm.v3 as __v3
    v3 = __v3
    import pulumi_kubernetes.helm.v4 as __v4
    v4 = __v4
else:
    v3 = _utilities.lazy_import('pulumi_kubernetes.helm.v3')
    v4 = _utilities.lazy_import('pulumi_kubernetes.helm.v4')

